@@ -13,6 +13,7 @@ import hashlib
 import json
 import os
 import re
+from typing import NamedTuple
 
 from calibre import fsync, prints, strftime
 from calibre.constants import DEBUG, filesystem_encoding
@@ -366,6 +367,18 @@ class KINDLE(USBMS):
                 db.add_books([bm.value['path']], ['txt'], [mi])
 
 
+class APNXOpts(NamedTuple):
+    send_apnx: bool = True
+    apnx_method: str = 'fast'
+    custom_col_name: str = ''
+    method_col_name: str = ''
+    overwrite: bool = True
+
+
+def get_apnx_opts() -> APNXOpts:
+    return APNXOpts(*KINDLE2.settings().extra_customization)
+
+
 class KINDLE2(KINDLE):
 
     name           = 'Kindle 2/3/4/Touch/PaperWhite/Voyage Device Interface'
@@ -463,7 +476,7 @@ class KINDLE2(KINDLE):
         if os.access(collections, os.R_OK):
             try:
                 self.kindle_update_booklist(bl, collections)
-            except:
+            except Exception:
                 import traceback
                 traceback.print_exc()
         return bl
@@ -513,7 +526,7 @@ class KINDLE2(KINDLE):
         # Upload the cover thumbnail
         try:
             self.upload_kindle_thumbnail(metadata, filepath)
-        except:
+        except Exception:
             import traceback
             traceback.print_exc()
         # Upload the apnx file
@@ -621,7 +634,7 @@ class KINDLE2(KINDLE):
         if cust_col_name:
             try:
                 custom_page_count = int(metadata.get(cust_col_name, 0))
-            except:
+            except Exception:
                 pass
 
         apnx_path = f'{os.path.join(path, filename)}.apnx'
@@ -638,10 +651,10 @@ class KINDLE2(KINDLE):
                             method = temp
                         else:
                             print(f'Invalid method choice for this book ({temp!r}), ignoring.')
-                    except:
+                    except Exception:
                         print('Could not retrieve override method choice, using default.')
                 apnx_builder.write_apnx(filepath, apnx_path, method=method, page_count=custom_page_count)
-            except:
+            except Exception:
                 print('Failed to generate APNX')
                 import traceback
                 traceback.print_exc()
